@@ -66,6 +66,22 @@ class FileReferenceList(UserList):
         return FileReferenceList(file_filter_fn(self.data, *args, **kwargs))
 
     def filter_list_by_path(self, directory=None, name=None, extension=None):
+        """Create a subset of this list by filtering the contents based on their path attributes
+
+        Parameters
+        ----------
+        directory : str, optional
+            Matches any of the directories in the file path, by default None
+        name : str, optional
+            Matches the name of the file, by default None
+        extension : str, optional
+            Matches the file extension, by default None
+
+        Returns
+        -------
+        FileReferenceList
+            Filtered list
+        """
         return self.filter_list(file_filters.custom_path_filter, directory, name, extension)
 
     def get_total_bytes(self):
