@@ -1,7 +1,6 @@
 import concurrent.futures
 import logging
 import tarfile
-from enum import Enum
 from functools import partial
 from pathlib import Path
 from tempfile import NamedTemporaryFile
@@ -12,6 +11,7 @@ from tqdm import tqdm
 
 from .bilby_job import BilbyJob
 from .file_reference import FileReference, FileReferenceList
+from .helpers import TimeRange, Cluster
 from .utils import rename_dict_keys, convert_dict_keys
 
 GWCLOUD_ENDPOINT = 'https://gwcloud.org.au/bilby/graphql'
@@ -26,15 +26,6 @@ ch.setLevel(logging.INFO)
 logger.addHandler(ch)
 
 
-class TimeRange(Enum):
-    """Enum to help with the time range field in the public job search."""
-    ANY = "Any time"
-    DAY = "Past 24 hours"
-    WEEK = "Past week"
-    MONTH = "Past month"
-    YEAR = "Past year"
-
-
 class GWCloud:
     """
     GWCloud class provides an API for interacting with Bilby, allowing jobs to be submitted and acquired.
@@ -54,7 +45,7 @@ class GWCloud:
     def __init__(self, token, endpoint=GWCLOUD_ENDPOINT):
         self.client = GWDC(token=token, endpoint=endpoint)
 
-    def start_bilby_job_from_string(self, job_name, job_description, private, ini_string):
+    def start_bilby_job_from_string(self, job_name, job_description, private, ini_string, cluster=Cluster.DEFAULT):
         """Submit the parameters required to start a Bilby job, using the contents of an .ini file
 
         Parameters
@@ -67,6 +58,8 @@ class GWCloud:
             True if job should be private, False if public
         ini_string : str
             The contents of a Bilby ini file
+        cluster : .Cluster or str
+            The name of the cluster to submit the job to
 
         Returns
         -------
@@ -89,10 +82,11 @@ class GWCloud:
                     "details": {
                         "name": job_name,
                         "description": job_description,
-                        "private": private
+                        "private": private,
+                        "cluster": cluster
                     },
                     "iniString": {
-                        "iniString": ini_string
+                        "iniString": str(ini_string)
                     }
                 },
             }
@@ -102,7 +96,7 @@ class GWCloud:
         job_id = data['newBilbyJobFromIniString']['result']['jobId']
         return self.get_job_by_id(job_id)
 
-    def start_bilby_job_from_file(self, job_name, job_description, private, ini_file):
+    def start_bilby_job_from_file(self, job_name, job_description, private, ini_file, cluster=Cluster.DEFAULT):
         """Submit the parameters required to start a Bilby job, using an .ini file
 
         Parameters
@@ -115,6 +109,8 @@ class GWCloud:
             True if job should be private, False if public
         ini_file : str or Path
             Path to an .ini file for running a Bilby job
+        cluster : .Cluster or str
+            The name of the cluster to submit the job to
 
         Returns
         -------
@@ -124,7 +120,7 @@ class GWCloud:
         ini_file = Path(ini_file)
         with ini_file.open() as f:
             ini_string = f.read().strip()
-            return self.start_bilby_job_from_string(job_name, job_description, private, ini_string)
+            return self.start_bilby_job_from_string(job_name, job_description, private, ini_string, cluster)
 
     def get_preferred_job_list(self):
         """Get list of public Bilby jobs corresponding to a search of "preferred" and a time_range of "Any time"
@@ -137,6 +133,9 @@ class GWCloud:
         return self.get_public_job_list(search="preferred lasky", time_range=TimeRange.ANY)
 
     def _get_job_model_from_query(self, query_data):
+        if not query_data:
+            # logger.info('No')
+            return None
         return BilbyJob(
             client=self,
             **rename_dict_keys(
@@ -156,7 +155,7 @@ class GWCloud:
         ----------
         search : str, optional
             Search terms by which to filter public job list, by default ""
-        time_range : TimeRange or str, optional
+        time_range : .TimeRange or str, optional
             Time range by which to filter job list, by default TimeRange.ANY
         number : int, optional
             Number of job results to return in one request, by default 100
@@ -193,6 +192,10 @@ class GWCloud:
 
         data = self.client.request(query=query, variables=variables)
 
+        if not data['publicBilbyJobs']['edges']:
+            logger.info('Job search returned no results.')
+            return []
+
         return [self._get_job_model_from_query(job['node']) for job in data['publicBilbyJobs']['edges']]
 
     def get_job_by_id(self, job_id):
@@ -229,6 +232,10 @@ class GWCloud:
 
         data = self.client.request(query=query, variables=variables)
 
+        if not data['bilbyJob']:
+            logger.info('No job matching input ID was returned.')
+            return None
+
         return self._get_job_model_from_query(data['bilbyJob'])
 
     def _get_user_jobs(self):
